/'
 ' Project Publisher - Installer Creator Addin for FbEdit, RadASM and MasmEd
 '
 ' Copyright (C) 2010 Arnel A. Borja (Galeon)
 '
 ' This program is free software: you can redistribute it and/or modify it under 
 ' the terms of the GNU General Public License as published by the Free Software 
 ' Foundation, either version 3 of the License, or (at your option) any later 
 ' version.
 '
 ' This program is distributed in the hope that it will be useful, but WITHOUT 
 ' ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 ' FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more 
 ' details.
 '
 ' You should have received a copy of the GNU General Public License along with 
 ' this program.  If not, see <http://www.gnu.org/licenses/>.
 '
 '/

'#Define _WIN32_IE &h0400

#Include Once "windows.bi"
#Include Once "win/commctrl.bi"
#Include Once "win/shellapi.bi"

#Include Once "Inc/FbEdit.bi"
#Include Once "Inc/RadASM2.bi"
#Include Once "Inc/RadASM3.bi"
#Include Once "Inc/MasmEd.bi"

#Include Once "ProjPub.bi"
#Include Once "FileFuncs.bi"
#Include Once "Settings.bi"
#Include Once "Header.bi"
#Include Once "Help.bi"
#Include Once "LangDll.bi"
#Include Once "Resource.bi"

Function LangDllDialogProc( _
	ByVal hWin As HWND, _
	ByVal uMsg As UINT, _
	ByVal wParam As WPARAM, _
	ByVal lParam As LPARAM _
	) As BOOL

	Select Case uMsg
		Case WM_INITDIALOG
			' Add header
			AddHeaderToPage( hWin, _
				GetTranslateString( "4020", "Supported Languages" ), _
				GetTranslateString( "4021", "Choose the languages you want your installer to support." ) _
				)

			' Translate dialog box
			TranslateAddinDialog( hWin )

			' Add languages to list box
			If LanguagesNum Then
				For i As Integer = 0 To LanguagesNum-1
					SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_ADDSTRING, NULL, Cast( LPARAM, Languages( i ).Name ) )
				Next
				SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_SETCURSEL, Cast( WPARAM, LanguageDefault ), NULL )
			End If

			' Set defaults
/'			Dim CurLanguage As Integer = GetLanguageId( ProjectSettings.Language )
			If CurLanguage <> -1 Then
				SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_SETCURSEL, Cast( WPARAM, CurLanguage ), NULL )
			End If
			'/
		Case WM_COMMAND
			'
		Case WM_CLOSE
			DestroyWindow(hWin)
			'
		Case WM_NOTIFY
			Select Case Cast( NMHDR Ptr, lParam )->code
				Case PSN_SETACTIVE
					PropSheet_SetWizButtons( Cast( NMHDR Ptr, lParam )->hwndFrom, PSWIZB_BACK Or PSWIZB_NEXT )
					'
			End Select
			'
		Case WM_HELP
			ShowContextHelp( Cast( HELPINFO Ptr, lParam ) )
			'
		Case Else
			Return FALSE
			'
	End Select

	Return TRUE

End Function


Sub LoadLanguages( _
	ByRef Location As Const String _
	)

	LanguagesNum = 0
	LanguagesMax = 0

	' Get first file
	Dim fname As String = Dir( Location & "\*.lng" )
	Dim size As Integer

	' Check if fname is valid
	Do While Len( fname )

		' Check FileType
		GetPrivateProfileString( "ProjPub", "FileType", "", @buffer, MAX_PATH, Location + "\" + fname )

		If buffer = "Language" Then

			' Check if the array can accomodate the number of files available
			If LanguagesNum >= LanguagesMax Then
	
				'' There are more files than the array can provide
				LanguagesMax += LANGUAGES_INCREASE
				ReDim Preserve Languages(LanguagesMax - 1) As Language
	
			End If
	
			' Set filename of the current language
			Languages( LanguagesNum ).DescFile = New Byte[Len(fname)+1]
			*Languages( LanguagesNum ).DescFile = fname
	
			' Set language info
			size = GetPrivateProfileString( "Language", "Name", "Unnamed", @buffer, MAX_PATH, Location + "\" + fname )
			Languages( LanguagesNum ).Name = New Byte[size+1]
			*Languages( LanguagesNum ).Name = buffer
	
			' Check if default is requested
			If GetPrivateProfileInt( "ProjPub", "Default", 0, Location + "\" + fname ) Then
				LanguageDefault = LanguagesNum
			End If
	
			' Increment Languages counter
			LanguagesNum += 1

		End If

		' Get next file name
		fname = Dir( "" )

	Loop

End Sub


Sub FreeLanguages( _
	)

	If LanguagesNum Then
		For i As Integer = 0 To LanguagesNum-1
			Delete[] Languages( i ).Name
			Delete[] Languages( i ).DescFile
		Next
	End If

End Sub


Function GetLanguageId( _
	ByRef filename As Const String _
	) As Integer

	If LanguagesNum Then
		For i As Integer = 0 To LanguagesNum-1
			If LCase( GetFileName( *Languages(i).DescFile ) ) = LCase( GetFileName( filename ) ) Then
				Return i
			End If
		Next
	End If

	Return -1

End Function


Function GetLanguageString( _
	ByVal LanguageId As Integer, _
	ByVal StringId As Integer, _
	ByRef Default As Const String _
	) As String

	If LanguageId >= 0 And LanguageId < LanguagesNum Then
		GetPrivateProfileString( "Strings", Str( StringId ), "", StrPtr( buffer ), MAX_PATH, Languages(LanguageId).DescFile )
	Else
		buffer = ""
	End If
	If buffer <> "" Then
		Return buffer
	Else
		Return Default
	End If

End Function

